@@ -129,7 +129,7 @@ typedef enum {
 } ncblitter_e;
 const char* notcurses_str_blitter(ncblitter_e blitter);
 int notcurses_lex_blitter(const char* op, ncblitter_e* blitter);
-uint32_t* ncplane_rgba(const struct ncplane* nc, ncblitter_e blit, int begy, int begx, int leny, int lenx);
+uint32_t* ncplane_as_rgba(const struct ncplane* nc, ncblitter_e blit, int begy, int begx, int leny, int lenx, int* pxdimy, int* pxdimx);
 char* ncplane_contents(const struct ncplane* nc, int begy, int begx, int leny, int lenx);
 void* ncplane_set_userptr(struct ncplane* n, void* opaque);
 void* ncplane_userptr(struct ncplane* n);
@@ -186,10 +186,10 @@ int ncplane_putstr_aligned(struct ncplane* n, int y, ncalign_e align, const char
 int ncplane_putstr_stained(struct ncplane* n, const char* s);
 int ncplane_putwstr_stained(struct ncplane* n, const wchar_t* gclustarr);
 struct ncplane* ncplane_dup(const struct ncplane* n, void* opaque);
-int cell_load(struct ncplane* n, cell* c, const char* gcluster);
-int cell_duplicate(struct ncplane* n, cell* targ, const cell* c);
-void cell_release(struct ncplane* n, cell* c);
-const char* cell_extended_gcluster(const struct ncplane* n, const cell* c);
+int nccell_load(struct ncplane* n, cell* c, const char* gcluster);
+int nccell_duplicate(struct ncplane* n, cell* targ, const cell* c);
+void nccell_release(struct ncplane* n, cell* c);
+const char* nccell_extended_gcluster(const struct ncplane* n, const cell* c);
 typedef struct palette256 {
   // We store the RGB values as a regular ol' channel
   uint32_t chans[256];
@@ -208,7 +208,7 @@ struct ncvisual* ncvisual_from_file(const char* file);
 struct ncvisual* ncvisual_from_rgba(const void* rgba, int rows, int rowstride, int cols);
 struct ncvisual* ncvisual_from_bgra(const void* rgba, int rows, int rowstride, int cols);
 struct ncvisual* ncvisual_from_plane(const struct ncplane* n, ncblitter_e blit, int begy, int begx, int leny, int lenx);
-int ncvisual_geom(const struct notcurses* nc, const struct ncvisual* n, const struct ncvisual_options* vopts, int* y, int* x, int* toy, int* tox);
+int ncvisual_blitter_geom(const struct notcurses* nc, const struct ncvisual* n, const struct ncvisual_options* vopts, int* y, int* x, int* toy, int* tox, ncblitter_e* blitter);
 void ncvisual_destroy(struct ncvisual* ncv);
 int ncvisual_decode(struct ncvisual* nc);
 int ncvisual_decode_loop(struct ncvisual* nc);
