@@ -11,7 +11,6 @@ CELL_ALPHA_TRANSPARENT = 0x20000000
 CELL_ALPHA_BLEND = 0x10000000
 CELL_ALPHA_OPAQUE = 0x00000000
 NCOPTION_INHIBIT_SETLOCALE = 0x0001
-NCOPTION_VERIFY_SIXEL = 0x0002
 NCOPTION_NO_WINCH_SIGHANDLER = 0x0004
 NCOPTION_NO_QUIT_SIGHANDLERS = 0x0008
 NCOPTION_SUPPRESS_BANNERS = 0x0020
@@ -95,7 +94,7 @@ class Cell:
         self.c.gcluster = egc # FIXME need use cell_load
 
     def __del__(self):
-        lib.cell_release(self.ncp.getNcplane(), self.c)
+        lib.nccell_release(self.ncp.getNcplane(), self.c)
 
     def setFgRGB(self, r, g, b):
         self.c.channels = channels_set_fg_rgb8(self.c.channels, r, g, b)
@@ -178,19 +177,19 @@ class Ncdirect:
         lib.ncdirect_stop(self.nc)
 
     def setFgRGB8(self, r, g, b):
-        if lib.ncdirect_fg_rgb8(self.nc, r, g, b):
+        if lib.ncdirect_set_fg_rgb8(self.nc, r, g, b):
             raise ValueError("Bad foreground RGB")
 
     def setBgRGB8(self, r, g, b):
-        if lib.ncdirect_bg_rgb8(self.nc, r, g, b):
+        if lib.ncdirect_set_bg_rgb8(self.nc, r, g, b):
             raise ValueError("Bad background RGB")
 
     def setFg(self, rgb):
-        if lib.ncdirect_fg_rgb(self.nc, rgb):
+        if lib.ncdirect_set_fg_rgb(self.nc, rgb):
             raise ValueError("Bad foreground RGB")
 
     def setBg(self, rgb):
-        if lib.ncdirect_bg_rgb(self.nc, rgb):
+        if lib.ncdirect_set_bg_rgb(self.nc, rgb):
             raise ValueError("Bad background RGB")
 
     def cursorEnable(self):
